==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="si" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 යෙදවුම මෙම පද්ධතිය සමඟ අනුකූල නොවේ</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>වසා දමන්න</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>සම්බන්ධ වෙමින්...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>වසා දමා ඇත</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම එක් කරන්න</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>දිනය/වේලාව</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>පැය-12 වේලාව</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>පැය-24 වේලාව</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>වේලා සැකසුම්</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>ජාලය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ජාලය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ජාල සැකසුම්</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>ඔබට අයිතම % 1 ක් ඉවත් කිරීමට අවශ්‍යද?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>මකා දමන්න</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>මෙම ක්‍රියාව ප්‍රතිස්ථාපනය කළ නොහැක</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>හඳුනානොගත් උපකරණය</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>හදුනානොගත් කාණ්ඩයකි</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>ඩිස්කය</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>විවෘත කරන්න</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>සියල්ල ගලවන්න</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>රදවනය </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>විචිත්‍ර ආකාරය</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>කාර්යක්ෂම ආකාරය</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ඉහළ</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>පහළ</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>වම</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>දකුණ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>පෙනීමට සලස්වා තබන්න</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>සඟවා තබන්න</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>ගැලපෙන ආකාරයට සඟවන්න</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ප්‍රකාරය</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>පිහිටුම</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>තත්ත්වය</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>ආධාරක යෙදවුම්</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>බහුකාර්ය පෙනුම</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>අහෝසි කරන්න</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>රැහැන් සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>ජාලය අක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>ජාලය සක්‍රීය කරන්න</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>ජාල සැකසුම්</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>උපාංගය අක්‍රීය කර ඇත</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>රැහැන් සම්බන්ධතාවය: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>සම්බන්ධතා නොමැත</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>සම්බන්ධ වෙමින් පවතී</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ජාලගතව ඇතත් අන්තර්ජාල ප්‍රවේශය නොමැත</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>ජාල කේබලය විසන්ධි කර ඇත</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>ජාලය</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>රැහැන්ගත ජාලය</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>රැහැන්ගත ජාලය %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>පවතින</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>සැකසුම්</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>බලය</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ධාරිතාව %1, මිනිත්තු %2 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ධාරිතාව %1, පැය %2 මිනිත්තු %3 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට මිනිත්තු %2</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට පැය %2 මිනිත්තු %3</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>ආරෝපිතයි</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>ධාරිතාවය %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 ආරෝපණය වෙමින්</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>ධාරිතාවය %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>ධාරිතාවය %1, සම්පූර්ණයෙන්ම ආරෝපිතයි</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>ඩෙස්ක්ටොප් එක පෙන්වන්න</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>අහෝසි කරන්න</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>බලය</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>වසා දමන්න </translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>තාවකාලිකව වසාදමන්න </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ශිශිරකරණය කරන්න</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>අගුළු දමන්න</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ඉවත් වන්න</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>පරිශීලක ගිණුම මාරු කරන්න</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>උපාංගය</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>හඩ ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>නිහඬ කරන්න</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ශබ්ද සැකසුම්</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>කාණ්ඩය %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ශබ්දය</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ලටපට </translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>අපද්‍රව්‍ය - %1 ගොනුව</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>අපද්‍රව්‍ය - ගොනු %1 </translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>විවෘත කරන්න</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>හිස්</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>පද්ධති තට්ටුව</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>රැහැන් රහිත සම්බන්ධතාවය</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>රැහැන් රහිත ජාලය %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="si" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 යෙදවුම මෙම පද්ධතිය සමඟ අනුකූල නොවේ</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>වසා දමන්න</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>සම්බන්ධ වෙමින්...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>වසා දමා ඇත</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම එක් කරන්න</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>දිනය/වේලාව</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>පැය-12 වේලාව</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>පැය-24 වේලාව</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>වේලා සැකසුම්</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>ඔබට අයිතම % 1 ක් ඉවත් කිරීමට අවශ්‍යද?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>මකා දමන්න</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>මෙම ක්‍රියාව ප්‍රතිස්ථාපනය කළ නොහැක</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>හඳුනානොගත් උපකරණය</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>හදුනානොගත් කාණ්ඩයකි</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>ඩිස්කය</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>විවෘත කරන්න</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>සියල්ල ගලවන්න</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>රදවනය </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>විචිත්‍ර ආකාරය</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>කාර්යක්ෂම ආකාරය</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ඉහළ</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>පහළ</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>වම</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>දකුණ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>පෙනීමට සලස්වා තබන්න</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>සඟවා තබන්න</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>ගැලපෙන ආකාරයට සඟවන්න</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ප්‍රකාරය</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>පිහිටුම</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>තත්ත්වය</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>ආධාරක යෙදවුම්</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>බහුකාර්ය පෙනුම</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>අහෝසි කරන්න</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>පවතින</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>සැකසුම්</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>බලය</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ධාරිතාව %1, මිනිත්තු %2 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ධාරිතාව %1, පැය %2 මිනිත්තු %3 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට මිනිත්තු %2</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට පැය %2 මිනිත්තු %3</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>ධාරිතාවය %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 ආරෝපණය වෙමින්</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>ධාරිතාවය %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>ධාරිතාවය %1, සම්පූර්ණයෙන්ම ආරෝපිතයි</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>ඩෙස්ක්ටොප් එක පෙන්වන්න</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>අහෝසි කරන්න</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>බලය</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>වසා දමන්න </translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>තාවකාලිකව වසාදමන්න </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ශිශිරකරණය කරන්න</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>අගුළු දමන්න</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ඉවත් වන්න</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>පරිශීලක ගිණුම මාරු කරන්න</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>උපාංගය</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>හඩ ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>නිහඬ කරන්න</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ශබ්ද සැකසුම්</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>කාණ්ඩය %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ශබ්දය</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ලටපට </translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>අපද්‍රව්‍ය - %1 ගොනුව</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>අපද්‍රව්‍ය - ගොනු %1 </translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>විවෘත කරන්න</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>හිස්</translation>
    </message>
</context>
</TS>
